@@ -21,7 +21,7 @@ our %EXPORT_TAGS = ( 'all' => \@EXPORT_OK, );
 sub _CERTIFICATE_HEADER_SIZE { return 40; }
 sub _MAX_PUBLIC_KEY_SIZE     { return 65_536; }
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 sub pin_sha256 {
     my ($path) = @_;
@@ -73,9 +73,7 @@ sub _process_pem_x509_certificate {
         $pem_encoded_public_key_string =
           _get_pem_encoded_public_key_string($x509);
     }
-    elsif ( $file_header =~
-        /^[-]{5}BEGIN[ ](?:X[.]?509|TRUSTED)[ ]CERTIFICATE[-]{5}/smx )
-    {
+    else {
         seek $handle, 0, Fcntl::SEEK_SET()
           or Carp::croak("Failed to seek to start of $path:$EXTENDED_OS_ERROR");
         defined read $handle, my $pem_encoded_certificate_string,
@@ -118,7 +116,7 @@ sub _check_for_der_encoded_public_key {
     my $asn = Convert::ASN1->new( encoding => 'DER' );
     $asn->prepare(
         <<"__SUBJECT_PUBLIC_KEY_INFO__") or Carp::croak( 'Failed to prepare SubjectPublicKeyInfo in ASN1:' . $asn->error() );
-SubjectPublicKeyInfo ::= SEQUENCE {
+SEQUENCE {
   algorithm SEQUENCE { algorithm OBJECT IDENTIFIER, parameters ANY OPTIONAL },
   subjectPublicKey BIT STRING
 }
@@ -127,12 +125,10 @@ __SUBJECT_PUBLIC_KEY_INFO__
         my $pub_key = $asn->decode($der_encoded_public_key_string)
           or Carp::croak(
             'Failed to decode SubjectPublicKeyInfo in ASN1:' . $asn->error() );
-        if ( $pub_key->{subjectPublicKey} ) {
-            $pem_encoded_public_key_string =
-                "-----BEGIN PUBLIC KEY-----\n"
-              . MIME::Base64::encode_base64($der_encoded_public_key_string)
-              . "-----END PUBLIC KEY-----\n";
-        }
+        $pem_encoded_public_key_string =
+            "-----BEGIN PUBLIC KEY-----\n"
+          . MIME::Base64::encode_base64($der_encoded_public_key_string)
+          . "-----END PUBLIC KEY-----\n";
     } or do {
         return;
     };
@@ -142,14 +138,7 @@ __SUBJECT_PUBLIC_KEY_INFO__
 sub _process_pem_public_key {
     my ( $handle, $file_header, $path ) = @_;
     my $pem_encoded_public_key_string;
-    if ( $file_header =~ /^[-]{5}BEGIN[ ]PUBLIC[ ]KEY[-]{5}/smx ) {
-        seek $handle, 0, Fcntl::SEEK_SET()
-          or Carp::croak("Failed to seek to start of $path:$EXTENDED_OS_ERROR");
-        defined read $handle, $pem_encoded_public_key_string,
-          _MAX_PUBLIC_KEY_SIZE()
-          or Carp::croak("Failed to read from $path:$EXTENDED_OS_ERROR");
-    }
-    elsif ( $file_header =~ /^[-]{5}BEGIN[ ]RSA[ ]PUBLIC[ ]KEY[-]{5}/smx ) {
+    if ( $file_header =~ /^[-]{5}BEGIN[ ]RSA[ ]PUBLIC[ ]KEY[-]{5}/smx ) {
         seek $handle, 0, Fcntl::SEEK_SET()
           or Carp::croak("Failed to seek to start of $path:$EXTENDED_OS_ERROR");
         defined read $handle, my $pem_encoded_rsa_public_key_string,
@@ -159,6 +148,13 @@ sub _process_pem_public_key {
             $pem_encoded_rsa_public_key_string);
         $pem_encoded_public_key_string = $pubkey->get_public_key_x509_string();
     }
+    else {
+        seek $handle, 0, Fcntl::SEEK_SET()
+          or Carp::croak("Failed to seek to start of $path:$EXTENDED_OS_ERROR");
+        defined read $handle, $pem_encoded_public_key_string,
+          _MAX_PUBLIC_KEY_SIZE()
+          or Carp::croak("Failed to read from $path:$EXTENDED_OS_ERROR");
+    }
     return $pem_encoded_public_key_string;
 }
 
@@ -184,7 +180,7 @@ HTTP::PublicKeyPins - Generate RFC 7469 HTTP Public Key Pin (HPKP) header values
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =head1 SYNOPSIS
 
@@ -211,7 +207,7 @@ This module allows the calculation of RFC 7469 HTTP Public Key Pin header values
 
 =head2 pin_sha256
 
-This function accepts the path to a L<X.509 Certificate|http://tools.ietf.org/html/rfc5280>.  It will load the public key from the certificate and prepare the appropriate value for the pin_sha256 parameter of the Public-Key-Pins value. This function will also make an attempt to read public keys (in PEM (L<SubjectPublicKeyInfo|http://tools.ietf.org/html/rfc5280#section-4.1.2.7> or L<PKCS#1|https://tools.ietf.org/html/rfc344> or DER format).
+This function accepts the path to a L<X.509 Certificate|http://tools.ietf.org/html/rfc5280>.  It will load the public key from the certificate and prepare the appropriate value for the pin_sha256 parameter of the Public-Key-Pins value. This function will also make an attempt to read public keys (in PEM (L<SubjectPublicKeyInfo|http://tools.ietf.org/html/rfc5280#section-4.1.2.7> or L<PKCS#1|https://tools.ietf.org/html/rfc344>) or DER format).
 
 =head1 SUBROUTINES/METHODS
 
@@ -249,8 +245,9 @@ HTTP::PublicKeyPins requires no configuration files or environment variables.
  
 HTTP::PublicKeyPins requires the following non-core modules
  
-  Crypt::OpenSSL::X509;
-  Crypt::OpenSSL::RSA;
+  Convert::ASN1
+  Crypt::OpenSSL::X509
+  Crypt::OpenSSL::RSA
   Digest
  
 =head1 INCOMPATIBILITIES
